@@ -11,6 +11,6 @@
 
 #define DDCUTIL_VMAJOR  2
 #define DDCUTIL_VMINOR  2
-#define DDCUTIL_VMICRO  4
-#define DDCUTIL_VSUFFIX dev
+#define DDCUTIL_VMICRO  6
+#define DDCUTIL_VSUFFIX DEV
 
